==> mrpt_1.0.2.orig.tar.gz: mrpt-1.0.2/libs/srba/include/mrpt/srba/impl/create_kf2kf_edge.h <==
/* +---------------------------------------------------------------------------+
   |                 The Mobile Robot Programming Toolkit (MRPT)               |
   |                                                                           |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2013, Individual contributors, see AUTHORS file        |
   | Copyright (c) 2005-2013, MAPIR group, University of Malaga                |
   | Copyright (c) 2012-2013, University of Almeria                            |
   | All rights reserved.                                                      |
   |                                                                           |
   | Redistribution and use in source and binary forms, with or without        |
   | modification, are permitted provided that the following conditions are    |
   | met:                                                                      |
   |    * Redistributions of source code must retain the above copyright       |
   |      notice, this list of conditions and the following disclaimer.        |
   |    * Redistributions in binary form must reproduce the above copyright    |
   |      notice, this list of conditions and the following disclaimer in the  |
   |      documentation and/or other materials provided with the distribution. |
   |    * Neither the name of the copyright holders nor the                    |
   |      names of its contributors may be used to endorse or promote products |
   |      derived from this software without specific prior written permission.|
   |                                                                           |
   | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       |
   | 'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED |
   | TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR|
   | PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS BE LIABLE |
   | FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL|
   | DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR|
   |  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)       |
   | HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,       |
   | STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN  |
   | ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE           |
   | POSSIBILITY OF SUCH DAMAGE.                                               |
   +---------------------------------------------------------------------------+ */

#pragma once

namespace mrpt { namespace srba {

template <class KF2KF_POSE_TYPE,class LM_TYPE,class OBS_TYPE,class RBA_OPTIONS>
size_t RbaEngine<KF2KF_POSE_TYPE,LM_TYPE,OBS_TYPE,RBA_OPTIONS>::create_kf2kf_edge(
	const TKeyFrameID        new_kf_id,
	const TPairKeyFrameID  & new_edge,
	const typename traits_t::new_kf_observations_t   & obs,
	const pose_t &init_inv_pose_val )
{
	// 1) Create new kf2kf structures (all but stuff related to the spanning trees)
	// ---------------------------------------------------------------------------------
	const size_t ed_id = rba_state.alloc_kf2kf_edge( new_edge, init_inv_pose_val );     // O(1)

	m_profiler.enter("define_new_keyframe.st.update_symbolic");

	// 2) Update symbolic spanning trees:
	// ---------------------------------------------------------------------------------
	rba_state.spanning_tree.update_symbolic_new_node(
		new_kf_id,
		new_edge,
		parameters.srba.max_tree_depth,
		(parameters.srba.edge_creation_policy==ecpLinearGraph),   // check_all_obs_are_connected
		&obs   // Only needed under the "linear graph" policy, to determine missing parts of the spanning tree to be filled in here
		);

	m_profiler.leave("define_new_keyframe.st.update_symbolic");

	return ed_id;
}

} } // end NS

==> mrpt_1.2.2.orig.tar.gz: mrpt-1.2.2/libs/srba/include/mrpt/srba/impl/create_kf2kf_edge.h <==
/* +---------------------------------------------------------------------------+
   |                     Mobile Robot Programming Toolkit (MRPT)               |
   |                          http://www.mrpt.org/                             |
   |                                                                           |
   | Copyright (c) 2005-2014, Individual contributors, see AUTHORS file        |
   | See: http://www.mrpt.org/Authors - All rights reserved.                   |
   | Released under BSD License. See details in http://www.mrpt.org/License    |
   +---------------------------------------------------------------------------+ */

#pragma once

namespace mrpt { namespace srba {

template <class KF2KF_POSE_TYPE,class LM_TYPE,class OBS_TYPE,class RBA_OPTIONS>
size_t RbaEngine<KF2KF_POSE_TYPE,LM_TYPE,OBS_TYPE,RBA_OPTIONS>::create_kf2kf_edge(
	const TKeyFrameID        new_kf_id,
	const TPairKeyFrameID  & new_edge,
	const typename traits_t::new_kf_observations_t   & obs,
	const pose_t &init_inv_pose_val )
{
	// 1) Create new kf2kf structures (all but stuff related to the spanning trees)
	// ---------------------------------------------------------------------------------
	const size_t ed_id = rba_state.alloc_kf2kf_edge( new_edge, init_inv_pose_val );     // O(1)

	m_profiler.enter("define_new_keyframe.st.update_symbolic");

	// 2) Update symbolic spanning trees:
	// ---------------------------------------------------------------------------------
	rba_state.spanning_tree.update_symbolic_new_node(
		new_kf_id,
		new_edge,
		parameters.srba.max_tree_depth,
		(parameters.srba.edge_creation_policy==ecpLinearGraph),   // check_all_obs_are_connected
		&obs   // Only needed under the "linear graph" policy, to determine missing parts of the spanning tree to be filled in here
		);

	m_profiler.leave("define_new_keyframe.st.update_symbolic");

	return ed_id;
}

} } // end NS
